instance

package
v1.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2020 License: Apache-2.0 Imports: 22 Imported by: 0

Documentation

Index

Constants

const FinalizerName = "harbor-operator.registries.mittwald.de"

Variables

This section is empty.

Functions

func Add

func Add(mgr manager.Manager) error

Add creates a new Instance Controller and adds it to the Manager. The Manager will set fields on the Controller and Start it when the Manager is Started.

Types

type ReconcileInstance

type ReconcileInstance struct {
	// contains filtered or unexported fields
}

ReconcileInstance reconciles a Instance object.

func (*ReconcileInstance) Reconcile

func (r *ReconcileInstance) Reconcile(request reconcile.Request) (reconcile.Result, error)

Reconcile reads that state of the cluster for a Instance object and makes changes based on the state read and what is in the Instance.Spec Note: The Controller will requeue the Request to be processed again if the returned error is non-nil or Result.Requeue is true, otherwise upon completion it will remove the work from the queue.

Jump to