Discover Packages
github.com/mittwald/harbor-operator
pkg
controller
instancechartrepo
package
Version:
v1.1.5
Opens a new window with list of versions in this module.
Published: Sep 10, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 18
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Add creates a new InstanceChartRepo Controller and adds it to the Manager.
The Manager will set fields on the Controller and Start it when the Manager is Started.
type ReconcileInstanceChartRepo struct {
}
ReconcileInstanceChartRepo reconciles a InstanceChartRepo object.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.