Documentation
¶
Index ¶
Constants ¶
const FinalizerName = "harbor-operator.registries.mittwald.de"
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ReconcileInstance ¶
type ReconcileInstance struct {
// contains filtered or unexported fields
}
ReconcileInstance reconciles a Instance object.
func (*ReconcileInstance) Reconcile ¶
Reconcile reads that state of the cluster for a Instance object and makes changes based on the state read and what is in the Instance.Spec Note: The Controller will requeue the Request to be processed again if the returned error is non-nil or Result.Requeue is true, otherwise upon completion it will remove the work from the queue.
Click to show internal directories.
Click to hide internal directories.