Documentation
¶
Index ¶
Constants ¶
const FinalizerName = "harbor-operator.registries.mittwald.de"
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ReconcileRegistry ¶
type ReconcileRegistry struct {
// contains filtered or unexported fields
}
ReconcileRegistry reconciles a Registry object.
func (*ReconcileRegistry) Reconcile ¶
Reconcile reads that state of the cluster for a Registry object and makes changes based on the state read and what is in the Registry.Spec Note: The Controller will requeue the Request to be processed again if the returned error is non-nil or Result.Requeue is true, otherwise upon completion it will remove the work from the queue.
Click to show internal directories.
Click to hide internal directories.